@@ -31,7 +31,7 @@ from .source.BasicSplinesModel import BasicSplinesModel
 from .source.BSplinesModel import BSplinesModel
 from .source.BaseFitter import BaseFitter
 from .source.BaseModel import BaseModel
-#from .source.BernouilliErrorDistribution import BernouilliErrorDistribution
+from .source.BernoulliErrorDistribution import BernoulliErrorDistribution
 from .source.BirthEngine import BirthEngine
 from .source.BracketModel import BracketModel
 #from .source.CategoricalFitter import CategoricalFitter
@@ -46,7 +46,7 @@ from .source.ClassicProblem import ClassicProblem
 from .source.CombiModel import CombiModel
 from .source.ConstantModel import ConstantModel
 from .source.ConvergenceError import ConvergenceError
-from .source.CrossEngine import CrossEngine
+#from .source.CrossEngine import CrossEngine
 from .source.CurveFitter import CurveFitter
 #from .source.CyclicResults import CyclicResults
 from .source.DeathEngine import DeathEngine
@@ -57,6 +57,7 @@ from .source.ErrorDistribution import ErrorDistribution
 from .source.ErrorsInXandYProblem import ErrorsInXandYProblem
 from .source.EtalonDriftModel import EtalonDriftModel
 from .source.EtalonModel import EtalonModel
+from .source.EvidenceProblem import EvidenceProblem
 from .source.ExpModel import ExpModel
 from .source.Explorer import Explorer
 from .source.ExponentialErrorDistribution import ExponentialErrorDistribution
@@ -90,7 +91,7 @@ from .source.LorentzModel import LorentzModel
 from .source.MaxLikelihoodFitter import MaxLikelihoodFitter
 from .source.MixedErrorDistribution import MixedErrorDistribution
 from .source.Model import Model
-#from .source.ModelLikelihood import ModelLikelihood
+from .source.ModelDistribution import ModelDistribution
 from .source.Modifiable import Modifiable
 from .source.MonteCarlo import MonteCarlo
 from .source.MultipleOutputProblem import MultipleOutputProblem
@@ -130,6 +131,7 @@ from .source.SineDriftModel import SineDriftModel
 from .source.SineModel import SineModel
 from .source.SineSplineDriftModel import SineSplineDriftModel
 from .source.SineSplineModel import SineSplineModel
+from .source.SoftMaxModel import SoftMaxModel
 from .source.SplinesModel import SplinesModel
 from .source.SplinesDynamicModel import SplinesDynamicModel
 from .source.StartEngine import StartEngine
@@ -161,6 +163,7 @@ from .source.Formatter import formatter
 from .source.Formatter import fma
 from .source.Formatter import formatter_init
 from .source.Plotter import plotFit
+from .source.Plotter import plotSampleList
 from .source.Tools import printclass
 from .source import Tools
 #from .source import bspline
