@@ -12,11 +12,11 @@ from . import Plotter
 from .Formatter import formatter as fmt
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.1"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  * This file is part of the BayesicFitting package.
 #  *
@@ -180,7 +180,7 @@ class BaseFitter( object ):
             self.xdata = self.imageAssistant.getIndices( xdata )
         else :
             self.imageAssistant = None
-            self.xdata = numpy.array( xdata )
+            self.xdata = numpy.asarray( xdata )
 
         if isinstance( xdata, Table ) :
             ndim = len( xdata.columns )
@@ -243,6 +243,10 @@ class BaseFitter( object ):
             ydata = self.imageAssistant.getydata( ydata )
             if weights is not None :
                 weights = self.imageAssistant.getydata( weights )
+        else :
+            ydata = numpy.asarray( ydata )
+            if weights is not None :
+                weights = numpy.asarray( weights )
 
         self.weights = weights
 
