@@ -13,11 +13,11 @@ from .ExponentialPrior import ExponentialPrior
 from .UniformPrior import UniformPrior
 
 __author__ = "Do Kester"
-__year__ = 2019
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.5.3"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 
 #  * This file is part of the BayesicFitting package.
@@ -106,6 +106,9 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
 
     """
 
+    NSPLITPRIOR = 3
+
+
     def __init__( self, ndim=1, depth=0, split=0.5, kdim=0, itypes=[0], modifiable=True,
                         dynamic=True, code=None, growPrior=None, copy=None, **kwargs ):
         """
@@ -185,8 +188,10 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
             setatt( self, "growPrior", growPrior )
             setatt( self, "itypes", itypes )
             setatt( self, "ncomp", ( 0x1 << depth ) - 1 )
-            setatt( self, "nsplit", 3 )
-            self.setLimits( 0, 1 )
+#            setatt( self, "nsplit", 3 )
+#            self.setLimits( 0, 1 )
+            setatt( self, "nsplit", self.NSPLITPRIOR )
+            self.setLimits( lowLimits=0.0, highLimits=1.0 )
         else :
             setatt( self, "growPrior", copy.growPrior )
             setatt( self, "ncomp", copy.ncomp )
@@ -230,6 +235,22 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
 
         return dtm
 
+    def __getattr__( self, name ) :
+        """
+        Return None when the named attribute has not been set.
+
+        Parameters
+        ----------
+        name : string
+            name of the attribute
+        """
+        if ( ( name == "split" ) or ( name == "mask" ) or ( name == "itypes" ) or
+             ( name == "dimension" ) or ( name == "maxComp" ) or ( name == "minComp" ) or
+             ( name == "parent" ) ) :
+            return None
+        else :
+            return super().__getattr__( name )
+
     def setSplitOrMask( self, itype, split ) :
         """ For internal use only """
 
@@ -792,8 +813,6 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
 
         """
         if self.ncomp < 1 or ( self.minComp is not None and self.ncomp <= self.minComp ):
-            print( "False in 1", self.ncomp, self.minComp )
-            print( self.fullName() )
             return False
 
         if rng is not None :
@@ -804,8 +823,6 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
 #       npp = parent.countLeaf()
 
         if parent is None :
-            print( "False in 2", location, id( leaf ) )
-            print( self.fullName( ids=True ) )
             return False
 
 
