@@ -6,9 +6,9 @@ from .Formatter import formatter as fmt
 from . import Tools
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.6.2"
+__version__ = "2.7.0"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -31,7 +31,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (Java code)
-#  *    2017 - 2020 Do Kester
+#  *    2017 - 2021 Do Kester
 
 
 threadErrors = []
@@ -158,10 +158,15 @@ class Explorer( object ):
         rng : RandomState
             random number generator
         """
+        if self.verbose >= 4 :
+            print( "-------- Start exploreWalker ---------------------------------" )
+#            self.checkWalkers()
 
         walker = self.walkers[kw]
         oldlogL = walker.logL
 
+        self.errdis.lowLhood = lowLhood
+
         maxmoves = len( walker.fitIndex ) / self.rate
         maxtrials = self.maxtrials / self.rate
 
@@ -171,10 +176,13 @@ class Explorer( object ):
         while moves < maxmoves and trials < maxtrials :
 
             for engine in rng.permutation( engines ) :
-                moves += engine.execute( kw, lowLhood, append=self.usePhantoms,iteration=self.iteration )
+                mv = engine.execute( kw, lowLhood, append=self.usePhantoms,iteration=self.iteration )
+                moves += mv
 
                 update = len( self.walkers ) - 1 if self.usePhantoms else kw
-                if self.verbose >= 4 or self.walkers[update].logL < lowLhood :
+#                if self.verbose >= 4 or self.walkers[update].logL < lowLhood :
+
+                if self.verbose >= 4 and mv > 0 :
                     wlkr = self.walkers[update]
                     print( "%4d %-15.15s %4d %10.3f %10.3f ==> %3d  %10.3f"%
                             ( trials, engine, update, lowLhood, oldlogL, moves,
@@ -246,6 +254,16 @@ class Explorer( object ):
         ValueError at inconsistency.
 
         """
+        walker.check( nhyp=self.errdis.nphypar )
+
+        if walker.problem.model.npars < len( walker.allpars ) - self.errdis.nphypar :
+            Tools.printclass( walker )
+            print( "Iteration %4d %4d %10.3f  %10.3f" % ( self.iteration, walker.id, walker.logL, wlogL ) )
+            print( fmt( walker.allpars, max=None ) )
+            raise ValueError( "Inconsistency in length of modelparams (%d) and allpars (%d - %d)" %
+                                ( walker.problem.model.npars, len( walker.allpars ), self.errdis.nphypar ) )
+
+
         wlogL = self.errdis.logLikelihood( walker.problem, walker.allpars )
         if wlogL != walker.logL :
             Tools.printclass( walker )
