@@ -7,9 +7,9 @@ from .Engine import Engine
 from .Engine import DummyPlotter
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.6.2"
+__version__ = "2.7.0"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -32,7 +32,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2017 - 2020 Do Kester
+#  *    2017 - 2021 Do Kester
 
 class GibbsEngine( Engine ):
     """
@@ -100,6 +100,11 @@ class GibbsEngine( Engine ):
         fitIndex = walker.fitIndex
 
         perm = self.rng.permutation( fitIndex )
+        if hasattr( self, "nstep" ) :
+            pm = perm
+            for k in range( 1, self.nstep ) :
+                perm = numpy.append( perm, pm )
+
         ur = self.unitRange * ( 1 + 2.0 / len( self.walkers ) )
 
         param = walker.allpars
