@@ -9,9 +9,9 @@ from .kernels.Kernel import Kernel
 from .kernels.Gauss import Gauss
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.5.3"
+__version__ = "2.8.0"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -34,7 +34,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2020 Do Kester
+#  *    2016 - 2021 Do Kester
 
 class Kernel2dModel( NonLinearModel ):
     """
@@ -214,7 +214,8 @@ class Kernel2dModel( NonLinearModel ):
             values for the parameters
 
         """
-        return self.shape2d.derivative( xdata, params )
+        df = self.shape2d.derivative( xdata, params )
+        return numpy.asarray( df ).T
 
     def basePartial( self, xdata, params, parlist=None ):
         """
