@@ -2,9 +2,9 @@ import numpy as numpy
 from .Model import Model
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.5.3"
+__version__ = "2.8.0"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -26,7 +26,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (JAVA code)
-#  *    2016 - 2020 Do Kester
+#  *    2016 - 2021 Do Kester
 
 class LinearModel( Model ):
     """
@@ -100,13 +100,12 @@ class LinearModel( Model ):
             values for the parameters.
 
         """
-        parlist = numpy.arange( self.npmax )
-        part = self.basePartial( xdata, params, parlist=parlist  )
+        part = self.basePartial( xdata, params )
 
         res = numpy.zeros( part.shape[0], dtype=float )
-
-        for k in parlist :
+        ## params might be a heterogeneous list of float or [float] from FixedModel
+        ## numpy.inner does not work here
+        for k in range( self.npmax ) :
             res += params[k] * part[:,k]
 
         return res
-
