@@ -22,6 +22,7 @@ from .Problem import Problem
 from .ClassicProblem import ClassicProblem
 from .ErrorsInXandYProblem import ErrorsInXandYProblem
 from .MultipleOutputProblem import MultipleOutputProblem
+from .EvidenceProblem import EvidenceProblem
 
 from .ErrorDistribution import ErrorDistribution
 from .ScaledErrorDistribution import ScaledErrorDistribution
@@ -31,7 +32,8 @@ from .PoissonErrorDistribution import PoissonErrorDistribution
 from .CauchyErrorDistribution import CauchyErrorDistribution
 from .UniformErrorDistribution import UniformErrorDistribution
 from .ExponentialErrorDistribution import ExponentialErrorDistribution
-#from .BernouilliErrorDistribution import BernouilliErrorDistribution
+from .ModelDistribution import ModelDistribution
+from .BernoulliErrorDistribution import BernoulliErrorDistribution
 
 from .Engine import Engine
 from .StartEngine import StartEngine
@@ -46,9 +48,9 @@ from .DeathEngine import DeathEngine
 from .StructureEngine import StructureEngine
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.6.2"
+__version__ = "2.8.1"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -71,7 +73,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (Java code)
-#  *    2017 - 2020 Do Kester
+#  *    2017 - 2021 Do Kester
 
 class NestedSampler( object ):
     """
@@ -107,12 +109,12 @@ class NestedSampler( object ):
 
     There are different likelihood functions available: Gaussian (Normal),
     Laplace (Norm-1), Uniform (Norm-Inf), Poisson (for counting processes),
-    Bernouilli (for categories), Cauchy (aka Lorentz) and
+    Bernoulli (for categories), Cauchy (aka Lorentz) and
     Exponential (generalized Gaussian).
     A mixture of ErrorDistributions can also be defined.
     By default the Gaussian distribution is used.
 
-    Except for Poisson and Bernouilli , all others are ScaledErrorDistributions.
+    Except for Poisson and Bernoulli , all others are ScaledErrorDistributions.
     The scale is a HyperParameter which can either be fixed, by setting the
     attribute errdis.scale or optimized, given the model parameters and the data.
     By default it is optimized for Gaussian and Laplace distributions.
@@ -208,7 +210,7 @@ class NestedSampler( object ):
     Author       Do Kester.
 
     """
-    TWOP32 = 2 ** 32
+    TWOP31 = 2 ** 31        ## 2 ** 32 raises an error on Windows systems.
     ENSEMBLE = 100
 
     #  *********CONSTRUCTORS***************************************************
@@ -259,7 +261,7 @@ class NestedSampler( object ):
             "poisson"       PoissonErrorDistribution no hyperpar
             "cauchy"        CauchyErrorDstribution with 1 hyperpar scale
             "uniform"       UniformErrorDistribution with 1 hyperpar scale
-            "bernouilli"    BernouilliErrorDistribution no hyperpar
+            "bernoulli"     BernoulliErrorDistribution no hyperpar
             "exponential"   ExponentialErrorDistribution with 2 hyperpar (scale, power)
 
             ErrorDistribution Externally defined ErrorDistribution
@@ -308,6 +310,16 @@ class NestedSampler( object ):
         if problem is None :
             problem = "classic"
 
+#        else :
+#            if model is None :
+#                model = problem.model
+#            if xdata is None :
+#                xdata = problem.xdata
+#            if ydata is None :
+#                ydata = problem.ydata
+#            if weights is None :
+#                weights = problem.weights
+
         self.setProblem( problem, model=model, xdata=xdata, ydata=ydata, weights=weights )
 
         if model is None :
@@ -374,7 +386,7 @@ class NestedSampler( object ):
         """
         keep = self.initSample( keep=keep )
 
-        self.initReport( keep=keep, plot=plot )
+        tail = self.initReport( keep=keep, plot=plot )
 
         explorer = Explorer( self, threads=self.threads )
 
@@ -399,7 +411,7 @@ class NestedSampler( object ):
 
             self.updateEvidence( worst )            # Update Z and H and store posterior samples
 
-            self.iterReport( worst - 1, plot=plot ) # some output when needed
+            self.iterReport( worst - 1, tail, plot=plot ) # some output when needed
 
             self.samples.weed( self.maxsize )       # remove overflow in samplelist
 
@@ -539,10 +551,25 @@ class NestedSampler( object ):
             if self.threads :
                 print( "Using threads." )
 
+        tail = 0
         if self.verbose > 1 :
-            print( "Iteration     logZ        H       LowL     npar     scale  parameters" )
+            while fitIndex[-tail-1] < 0 : 
+                tail += 1
 
-    def iterReport( self, kw, plot=False ) :
+#            tail = self.distribution.nphypar
+            if tail == 0 :
+                print( "Iteration     logZ        H       LowL     npar parameters" )
+            else :
+                print( "Iteration     logZ        H       LowL     npar parameters", end="" )
+                for k in range( 1,  min( 5, len( fitIndex ) - tail ) ) :
+                    print( "        ", end="" )
+                for k in range( tail ) :
+                    print( "   %s" %self.distribution.hyparname( k ), end="" )
+                print( "" )
+
+        return tail
+
+    def iterReport( self, kw, tail, plot=False ) :
 
         if self.verbose >= 3 or ( self.verbose >= 1 and
                                   self.iteration % 100 == 0 ):
@@ -555,10 +582,12 @@ class NestedSampler( object ):
             else :
                 pl = self.walkers[kw].allpars[self.walkers[kw].fitIndex]
                 np = len( pl )
-#               scale = self.getScale( self.walker[kw] )
+#                tail = self.distribution.nphypar
                 print( "%8d %#10.3g %8.1f %#10.3g %6d "%( self.iteration, self.logZ,
-                    self.info, self.lowLhood, np ), fmt( pl[-1] ), fmt( pl ) )
-#                    fmt( self.end ), self.ensemble, self.worst, fmt( self.getMaxIter() ) )
+                    self.info, self.lowLhood, np ), fmt( pl, max=4, tail=tail ) )
+#                print( "%-16.16s " % self.engines[1], end="" )
+#                self.engines[1].printReport()
+
 
             self.plotResult( self.walkers[kw], self.iteration, plot=self.doIterPlot( plot ) )
 
@@ -577,7 +606,9 @@ class NestedSampler( object ):
             self.report()
 
         if self.doLastPlot( plot ) :
-            Plotter.plotFit( self.problem.xdata, self.problem.ydata, yfit=self.yfit, residuals=True )
+#            Plotter.plotFit( self.problem.xdata, self.problem.ydata, yfit=self.yfit, residuals=True )
+            Plotter.plotSampleList( self.samples, self.problem.xdata, self.problem.ydata, 
+                    figsize=[12,8], residuals=True )
 
     def getMaxIter( self ) :
         """
@@ -585,6 +616,39 @@ class NestedSampler( object ):
         """
         return max( self.minimumIterations, self.end * self.ensemble * self.info / self.worst )
 
+    def getMaxIterMED( self ) :
+        """
+        Return the maximum number of iteration in case of EvidenceProblem.
+        """
+        try :
+            self.csEvid += [math.exp( self.logZ )]
+        except :
+            self.csEvid = [math.exp( self.logZ )]
+
+        if self.iteration < self.minimumIterations :
+            return self.minimumIterations
+
+        kmed = 0
+        medlim = 0.5 * self.csEvid[-1]
+        for cs in self.csEvid :
+            if cs > medlim : break
+            kmed += 1
+
+        return self.end * kmed
+
+
+    def getMaxIterEP( self ) :
+        """
+        Return the maximum number of iteration in case of EvidenceProblem.
+        """
+        if self.iteration < self.minimumIterations :
+            return self.minimumIterations
+        if ( self.samples[-1].logW < self.samples[-100].logW and 
+             self.samples[-1].logW < self.logZ - 16 ) :
+            return self.iteration
+        else :
+            return self.iteration + 100  
+
 #   det getScale( self, walker ) :
 #       np = walker.model.npchain
 #       return self.distribution.getScale( walker.model, params=walker.allpars[:np] )
@@ -766,7 +830,8 @@ class NestedSampler( object ):
         problemdict = {
             "classic"  : ClassicProblem,
             "errors"   : ErrorsInXandYProblem,
-            "multiple" : MultipleOutputProblem
+            "multiple" : MultipleOutputProblem,
+            "evidence" : EvidenceProblem
         }
 #           "salesman" : SalesmanProblem
 #           "order" : OrderProblem
@@ -774,9 +839,6 @@ class NestedSampler( object ):
         if isinstance( name, Problem ) :
             self.problem = name
             if model is not None : self.problem.model = model
-#            if xdata is not None : self.problem.xdata = xdata
-#            if ydata is not None : self.problem.ydata = ydata
-#            if weights is not None : self.problem.weights = weights
             if xdata is not None : self.problem.xdata = numpy.asarray( xdata )
             if ydata is not None : self.problem.ydata = numpy.asarray( ydata )
             if weights is not None : self.problem.weights = numpy.asarray( weights )
@@ -805,7 +867,7 @@ class NestedSampler( object ):
             None    distribution is Problem dependent.
             string  name of distribution; one of
                     "gauss", "laplace", "poisson", "cauchy", "uniform",
-                    "exponential", "bernouilli (TBD)"
+                    "exponential", "bernoulli"
             ErrorDistribution use this one
         limits : None or [low,high] or [[low],[high]]
             None    no limits implying fixed hyperparameters (scale,power,etc)
@@ -841,8 +903,12 @@ class NestedSampler( object ):
             self.distribution = UniformErrorDistribution( scale=scale, limits=limits )
         elif name == "exponential" :
             self.distribution = ExponentialErrorDistribution( scale=scale, power=power, limits=limits )
-#        elif name == "bernouilli" :
-#            self.distribution = BernouilliErrorDistribution()
+        elif name == "model" :
+            self.distribution = ModelDistribution( scale=scale, limits=limits )
+#            self.getMaxIter = self.getMaxIterEP
+#            self.minimumIterations = max( self.minimumIterations, 100 )
+        elif name == "bernoulli" :
+            self.distribution = BernoulliErrorDistribution()
         else :
             raise ValueError( "Unknown error distribution %s" % name )
 
@@ -894,7 +960,7 @@ class NestedSampler( object ):
 
             try :
                 Eng = enginedict[name]
-                seed = self.rng.randint( self.TWOP32 )
+                seed = self.rng.randint( self.TWOP31 )
                 engine = Eng( self.walkers, self.distribution,
                               seed=seed, verbose=self.verbose )
             except :
@@ -934,16 +1000,21 @@ class NestedSampler( object ):
             try :
                 name = self.problem.myStartEngine()
                 StartEng = startdict[name]
-                seed = self.rng.randint( self.TWOP32 )
+                seed = self.rng.randint( self.TWOP31 )
                 self.initialEngine = StartEng( self.walkers, self.distribution,
                         seed=seed )
             except :
                 raise ValueError( "Unknown StartEngine name : %10s" % name )
 
         # Calculate logL for all walkers.
+        self.distribution.lowLhood = -math.inf
         for walker in self.walkers :
             self.initialEngine.execute( walker.id, -math.inf )
 
+#        for w in self.walkers :
+#            print( w.id, w.problem.model.npars, len( w.problem.model.parameters), len( w.allpars) )
+#            w.check( nhyp=self.distribution.nphypar )
+
     def plotData( self, plot=False ):
         """
         Initialize the plot with data.
