@@ -1,13 +1,14 @@
 import numpy as numpy
 from . import Tools
 from .Tools import setAttribute as setatt
+from .Formatter import formatter as fmt
 
 from .LinearModel import LinearModel
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.5.3"
+__version__ = "2.8.0"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -30,7 +31,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (Java code)
-#  *    2017 - 2020 Do Kester
+#  *    2017 - 2021 Do Kester
 
 class PolySurfaceModel( LinearModel ):
     """
@@ -72,7 +73,15 @@ class PolySurfaceModel( LinearModel ):
     """
     def __init__( self, degree, copy=None, **kwargs ):
         """
-        Polynominal surface of a certain degree.
+        Polynominal surface of a certain degree. Two dimensions.
+
+        degree      polysurface
+          0         p_0
+          1         p_0 + p_1 * x + p_2 * y
+          2         p_0 + p_1 * x + p_2 * y + p_3 * x^2 + p_4 * x * y + p_5 * y^2
+          3         p_0 + p_1 * x + p_2 * y + p_3 * x^2 + p_4 * x * y + p_5 * y^2 +
+                        p_6 * x^3 + p_7 * x^2 * y + p_8 * x * y^2 + p_9 * y^3
+        etc.
 
         The number of parameters is ( degree+2 ) * ( degree+1 ) / 2
 
@@ -143,6 +152,81 @@ class PolySurfaceModel( LinearModel ):
 
         return part[:,parlist]
 
+    def baseDerivative( self, xdata, params ) :
+        """
+        Return the derivative df/dx at each input (=x).
+
+        degree      df/dx
+          0         0
+          1         p_1
+          2         p_1 + 2 * p_3 * x + p_4 * y
+          3         p_1 + 2 * p_3 * x + p_4 * y + 3 * p_6 * x^2 + 2 * p_7 * x * y + p_8 * y^2
+
+        degree      df/dy
+          0         0
+          1         p_2
+          2         p_2 + p_4 * x + 2 * p_5 * y
+          3         p_2 + p_4 * x + 2 * p_5 * y + p_7 * x^2 + 2 * p_8 * x * y + 3 * p_9 * y^2
+
+
+        Parameters
+        ----------
+        xdata : array_like
+            values at which to calculate the partials
+        params : array_like
+            parameters for the model.
+
+        """
+        if self.npmax <= 1 :
+            return numpy.zeros_like( xdata )
+
+        np = self.npmax
+
+        if not hasattr( self, "xindex" ) :
+            indx = []
+            fact = []
+            n = 1
+            k = 1
+            while k < np :
+                print( np, k, n )
+                indx += [i for i in range( k, k+n )]
+                fact += [n-f for f in range( n )]
+                k += n + 1
+                n += 1
+
+                print( "X  ", fmt( indx, max=None ), fmt( fact, max=None ) )
+
+            setatt( self, "xindex", indx )
+            setatt( self, "xfact", fact )
+
+            indx = []
+            fact = []
+            k = 2
+            n = 1
+            while k < np :
+                print( np, k, n )
+                indx += [i for i in range( k, k+n )]
+                fact += [f+1 for f in range( n )]
+                k += n + 1
+                n += 1
+
+                print( "Y  ", fmt( indx, max=None ), fmt( fact, max=None ) )
+
+            setatt( self, "yindex", indx )
+            setatt( self, "yfact", fact )
+
+
+        p = params[self.xindex] * self.xfact
+        deg  = self.degree - 1
+
+        dfdx = PolySurfaceModel( deg ).result( xdata, p )
+
+        p = params[self.yindex] * self.yfact
+        dfdy = PolySurfaceModel( deg ).result( xdata, p )
+
+        return numpy.append( dfdx, dfdy ).reshape( 2, -1 ).T
+
+
     def baseName( self ):
         """
         Returns a string representation of the model.
