@@ -6,9 +6,9 @@ from .Tools import setAttribute as setatt
 from .Tools import printclass
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.6.2"
+__version__ = "2.8.0"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -32,7 +32,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2020 Do Kester
+#  *    2016 - 2021 Do Kester
 
 class Prior( object ):
     """
@@ -47,7 +47,9 @@ class Prior( object ):
 
     d is a value in the domain of the prior and u is a vlue in [0,1]
 
-    The handling of limits is relegated to this Prior class
+    The handling of limits is relegated to this Prior class. Define
+        _umin = domain2Unit( lowLimit )
+        _urng = domain2Unit( highLimit ) - umin
 
         u = ( domain2Unit( d ) - umin ) / urange
         d = unit2Domain( u * urange + umin )
@@ -84,6 +86,10 @@ class Prior( object ):
         urange (hi-lo) in unit
     """
 
+##  TBD : 1. change all self.attribute = value to setattr( "attribute, value )
+##        2. forbid external settings of (most) attributes except through methods
+
+
     #*********CONSTRUCTORS***************************************************
     def __init__( self, limits=None, circular=False, domain=[-math.inf,math.inf],
                   prior=None ):
