@@ -12,11 +12,11 @@ from .UniformPrior import UniformPrior
 from .Prior import Prior
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2020
 __license__ = "GPL"
-__version__ = "1.0"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.5.3"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  *
 #  * This file is part of the BayesicFitting package.
