@@ -1,15 +1,17 @@
 import numpy as numpy
 from astropy import units
 import math
+import warnings
 from . import Tools
 from .Formatter import formatter as fmt
 from .Dynamic import Dynamic
 from .Engine import Engine
+from .ErrorsInXandYProblem import ErrorsInXandYProblem
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.6.0"
+__version__ = "2.7.2"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -32,7 +34,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2017 - 2020 Do Kester
+#  *    2017 - 2021 Do Kester
 
 class StartEngine( Engine ):
     """
@@ -91,6 +93,7 @@ class StartEngine( Engine ):
         maxtrials = self.maxtrials
         if hasattr( self.errdis, "constrain" ) and callable( self.errdis.constrain ) :
             maxtrials *= 100
+
         ktry = 0
         while True :
 
@@ -129,11 +132,16 @@ class StartEngine( Engine ):
 
         self.setWalker( walker.id, problem, allp, logL, fitIndex=fitIndex )
 
-
         wlkr = self.walkers[walker.id]
-        wlkr.check( nhyp=self.errdis.nphypar )
-#        print( fmt( walker.id ), fmt( wlkr.allpars ), fmt( wlkr.logL ), fmt( allp ), fmt( logL ) )
+#        print( walker.id, wlkr.id, wlkr.problem.model.npars, len( wlkr.allpars ), fmt( wlkr.logL ) )
+
+        nhyp = self.errdis.nphypar 
+        
+        nuisance = len( problem.xdata ) if isinstance( problem, ErrorsInXandYProblem ) else 0
+
+        wlkr.check( nhyp=nhyp, nuisance=nuisance )
 
         return len( fitIndex )
 
 
+
