@@ -6,11 +6,11 @@ from . import Tools
 from .Formatter import formatter as fmt
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL"
-__version__ = "1.0"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.2"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  *
 #  * This file is part of the BayesicFitting package.
@@ -79,16 +79,20 @@ class StructureEngine( Engine ):
         return str( "StructureEngine" )
 
     #  *********EXECUTE***************************************************
-    def execute( self, walker, lowLhood ):
+    def execute( self, kw, lowLhood, append=False, iteration=0 ):
         """
         Execute the engine by changing a component.
 
         Parameters
         ----------
-        walker : Sample
-            walker to diffuse
+        kw : int
+            index of walker to diffuse
         lowLhood : float
             lower limit in logLikelihood
+        append : bool
+            set walker in place or append in walkerlist
+        iteration : int
+            iteration number
 
         Returns
         -------
@@ -99,15 +103,17 @@ class StructureEngine( Engine ):
 
         t = 0
         k = 0
-        perm = self.rng.permutation( walker.problem.model.ncomp - 2 )
+        perm = self.rng.permutation( self.walkers[kw].problem.model.ncomp - 2 )     ## TBC
         for p in perm :
-            dt = self.executeOnce( walker.id, lowLhood, location=p+1 )
-            k = 0 if dt > 0 else k + 1
+            update = len( self.walkers ) if append else kw
+            dt = self.executeOnce( kw, lowLhood, update, location=p+1 )
+            if dt > 0 :
+                kw = update
             t += dt
 
         return t
 
-    def executeOnce( self, wlkrid, lowLhood, location=None ) :
+    def executeOnce( self, wlkrid, lowLhood, update, location=None ) :
         """
         One execution call.
         """
@@ -120,7 +126,7 @@ class StructureEngine( Engine ):
 
         if self.verbose > 4 :
             print( "SEN0  ", walker.id, walker.parent, len( ptry ), len( ftry ), walker.logL )
-            print( "      ", fmt( cwalker.problem.model.knots, max=None ) )
+            print( "      ", fmt( problem.model.knots, max=None ) )
 
         off = 0
         model = problem.model
@@ -142,18 +148,15 @@ class StructureEngine( Engine ):
 
         if self.verbose > 4 :
             print( "SEN3  ", fmt( ptry, max=None ), Ltry, lowLhood )
-            print( "      ", fmt( cwalker.problem.model.knots, max=None ) )
+            print( "      ", fmt( problem.model.knots, max=None ) )
 
         if Ltry >= lowLhood:
             self.reportSuccess()
-            self.setWalker( cwalker, problem, ptry, Ltry, fitIndex=ftry )
-            wlkr = self.walkers[walker.id]
+            self.setWalker( update, problem, ptry, Ltry, fitIndex=ftry )
+            wlkr = self.walkers[update]
 
             wlkr.check( nhyp=self.errdis.nphypar )
 
-            ## check if better than Lbest in walkers[-1]
-            self.checkBest( problem, ptry, Ltry, ftry )
-
             return 1
 
         self.reportFailed()
