@@ -10,9 +10,9 @@ import re
 from astropy.table import Table
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "2.5.3"
+__version__ = "2.8.0"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -30,7 +30,7 @@ __status__ = "Perpetual Beta"
 #  *
 #  * The GPL3 license can be found at <http://www.gnu.org/licenses/>.
 #  *
-#  *    2016 - 2020 Do Kester
+#  *    2016 - 2021 Do Kester
 
 
 def getItem( ilist, k ) :
@@ -370,10 +370,16 @@ def shortName( val ):
 
 def nicenumber( x ) :
     """
-    Return a nice number close to x.
+    Return a nice number close to (but below) |x|.
     """
     if x == 0 :
         return x
+    if x < 0 :
+        sgn = -1
+        x = abs( x )
+    else :
+        sgn = 1
+
     n = 1.0
     while x > 10 :
         x /= 10
@@ -381,7 +387,7 @@ def nicenumber( x ) :
     while x < 1 :
         x *= 10
         n /= 10
-    return int( x ) * n
+    return sgn * int( x ) * n
 
 def fix2int( x ) :
     """
