@@ -56,7 +56,7 @@ class TestEngine2( unittest.TestCase ):
 
         xdata = numpy.linspace( 0.0, 10.0, np )
         data = numpy.ceil( numpy.arange( np, dtype=float ) / 2.3 + 2.4 )
-        numpy.random.seed( 345345 )
+        numpy.random.seed( 4534 )
         data += 0.4 * numpy.random.randn( np )
 #        print( data )
         numpy.set_printoptions( precision=3, suppress=True )
@@ -74,13 +74,9 @@ class TestEngine2( unittest.TestCase ):
         print( "\n   Step Engine Test\n" )
         self.stdenginetest( StepEngine, iter=1001, nsamp=10, plot=self.doplot )
 
-#    def testCrossEngine( self ):
-#        print( "\n   Cross Engine Test\n" )
-#        self.stdenginetest( CrossEngine, iter=800, nsamp=100, plot=self.doplot )
-
     def testGalileanEngine( self ):
         print( "\n   Galilean Engine Test\n" )
-        self.stdenginetest( GalileanEngine, iter=101, nsamp=10, plot=self.doplot )
+        self.stdenginetest( GalileanEngine, iter=201, nsamp=10, plot=self.doplot )
 
     def testChordEngine( self ):
         print( "\n   Chord Engine Test\n" )
@@ -159,6 +155,10 @@ class TestEngine2( unittest.TestCase ):
             plt.plot( pevo[:,0], pevo[:,1], 'r.' )
             plt.show()
 
+        print( lowL, mmx )
+        print( p1[0], mk0, abs( p1[0] - mk0 ) )
+        print( p1[1], mk1, abs( p1[1] - mk1 ) )
+
         self.assertTrue( lowL > mmx )
         self.assertTrue( abs( p1[0] - mk0 ) < 1 )
         self.assertTrue( abs( p1[1] - mk1 ) < 1 )
