@@ -13,15 +13,15 @@ import matplotlib.pyplot as plt
 
 from BayesicFitting import *
 from BayesicFitting import formatter as fmt
-from MultiDimAverageModel import MultiDimAverageModel
-from BoxedErrorDistribution import BoxedErrorDistribution
+#from MultiDimAverageModel import MultiDimAverageModel
+#from BoxedErrorDistribution import BoxedErrorDistribution
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2021
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.7.3"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  *
 #  * This file is part of the BayesicFitting package.
@@ -38,7 +38,7 @@ __status__ = "Development"
 #  *
 #  * The GPL3 license can be found at <http://www.gnu.org/licenses/>.
 #  *
-#  *  2017 Do Kester
+#  *  2017 - 2021  Do Kester
 
 class TestErrorDistribution( unittest.TestCase ):
     """
@@ -260,15 +260,15 @@ class TestErrorDistribution( unittest.TestCase ):
                 param[1] += 1
             print( "" )
 
-    def constrainBox( self, logL, problem, allpars ):
+    def constrainBox( self, logL, problem, allpars, logLlow ):
         box = [-2,2]
         for p in allpars[:-1] :
             if ( p < box[0] ) or ( p > box[1] ) :
-                return -math.inf
+                return logLlow - 1
 
         return logL
 
-    def testGaussErrorDistribution1( self ):
+    def XXXtestGaussErrorDistribution1( self ):
 
         print( "=======   Test Gauss Error Distribution 1 ==================" )
 
@@ -312,6 +312,7 @@ class TestErrorDistribution( unittest.TestCase ):
         lLdata = ged.logLdata( problem, param )
         logL0 = numpy.sum( lLdata )
 
+        ged.lowLhood = -math.inf        ## is normally set by NS
         logL = ged.logLikelihood( problem, param )
         altL = ged.logLikelihood_alt( problem, param )
         print( "logL  = %8.3f  %8.3f  %8.3f" % ( logL, logL0, altL ) )
@@ -678,6 +679,24 @@ class TestErrorDistribution( unittest.TestCase ):
                 param[1] += 1
             print( "" )
 
+    def testModelDistribution( self ):
+        print( "====== Test Model Distribution ======================" )
+        poly = PolynomialModel( 1 )
+        param = numpy.asarray( [12, 10], dtype=float )
+        data = numpy.asarray( self.data + 13, dtype=int )
+        print( "Data : ", data )
+
+        problem = ClassicProblem( model=poly, xdata=self.x, ydata=data )
+
+        ed = ModelDistribution( limits=[0.01,10] )
+        printclass( ed )
+
+
+
+
+
+
+
     def testPoissonErrorDistribution( self ):
         print( "====== Test Poisson Error Distribution ======================" )
         poly = PolynomialModel( 1 )
@@ -735,17 +754,20 @@ class TestErrorDistribution( unittest.TestCase ):
             print( "" )
 
 
-    def XXXtestBernouilliErrorDistribution( self ):
-        print( "====== Test Bernouilli Error Distribution ======================" )
+    def testBernoulliErrorDistribution( self ):
+        print( "====== Test Bernoulli Error Distribution ======================" )
         poly = LogisticModel( fixed={0:1} )
-        param = numpy.asarray( [0, 1], dtype=float )
+        param = numpy.asarray( [0,1], dtype=float )
         data = numpy.asarray( [0,0,0,0,0,1,1,1,1,1,1], dtype=int )
+        data = numpy.asarray( [1,1,1,1,1,1,0,0,0,0,0], dtype=int )
+
+        print( "x    : ", fmt( self.x, max=None ) )
         print( "Data : ", fmt( data, max=None ) )
         print( "yfit : ", fmt( poly.result( self.x, param ), max=None ) )
 
         problem = ClassicProblem( model=poly, xdata=self.x, ydata=data )
 
-        ped = BernouilliErrorDistribution( )
+        ped = BernoulliErrorDistribution( )
         self.assertFalse( ped.acceptWeight() )
 
         logL = ped.logLikelihood( problem, param )
@@ -767,10 +789,10 @@ class TestErrorDistribution( unittest.TestCase ):
 
         fitIndex = [0,1]
         dL = ped.partialLogL( problem, param, fitIndex )
-        aL = ped.partialLogL_alt( problem, param, fitIndex )
+#        aL = ped.partialLogL_alt( problem, param, fitIndex )
         nL = ped.numPartialLogL( problem, param, fitIndex )
         print( "partial = ", dL )
-        print( "altpart = ", aL )
+#        print( "altpart = ", aL )
         print( "numpart = ", nL )
         assertAAE( dL, nL, 5 )
 
